Pool

Struct Pool 

pub struct Pool { /* private fields */ }
Validator pool that keeps requested transactions.

Implementations

Source

impl Pool

pub fn new() -> Self

Create an empty pool.

pub fn clear(&mut self)

Clear pool.

pub fn add(&mut self, group: Group, sender: U256)

Add a new group. sender must correspond to the group sender that is required on group creation.

pub fn update(&mut self, state: &State, schema: &Schema)

Update the pool according to the given state. Valid group in one state may be invalid in another. This function recalculates senders based on the state, so it may take a while.

pub fn prepare<R: Rng>( &self, rng: &mut R, state: &State, schema: &Schema, validator_key: &U256, groups_max: Option<usize>, ) -> (Vec<Transaction>, Vec<U256>)

Prepare transactions and senders for the next block. The pool must be updated according to this state.